@@ -1,4 +1,7 @@
 package Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp;
+{
+  $Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp::DIST = 'Catalyst-Plugin-ErrorCatcher-ActiveMQ-Stomp';
+}
 
 use Moose;
 use Net::Stomp;
@@ -14,9 +17,13 @@ use Fcntl qw(:flock);
 
 Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp - The great new Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp!
 
+=head1 VERSION
+
+version 0.001002
+
 =cut
 
-use version; our $VERSION = qv(0.1.1)->numify;
+use version; our $VERSION = qv(0.1.0)->numify;
 
 
 class_type 'Data::Serializer';
